@@ -238,8 +238,8 @@ class StrawberryField(dataclasses.Field):
                 return result.value
 
             if field_.is_list:
-                assert self.child is not None
-                return [_convert_enums_to_values(self.child, item) for item in result]
+                assert field_.child is not None
+                return [_convert_enums_to_values(field_.child, item) for item in result]
 
             return result
 
@@ -250,7 +250,7 @@ class StrawberryField(dataclasses.Field):
                 context=info.context,
                 root_value=info.root_value,
                 variable_values=info.variable_values,
-                return_type=self.type,
+                return_type=self._get_return_type(),
                 operation=info.operation,
                 path=info.path,
             )
@@ -274,6 +274,21 @@ class StrawberryField(dataclasses.Field):
         _resolver._is_default = not self.base_resolver  # type: ignore
         return _resolver
 
+    def _get_return_type(self):
+        # using type ignore to make mypy happy,
+        # this codepath will change in future anyway, so this is ok
+        if self.is_list:
+            assert self.child
+
+            type_ = List[self.child._get_return_type()]  # type: ignore
+        else:
+            type_ = self.type
+
+        if self.is_optional:
+            type_ = Optional[type_]  # type: ignore
+
+        return type_
+
 
 def field(
     resolver: Optional[_RESOLVER_TYPE] = None,
