@@ -1,5 +1,6 @@
 import datetime
 import decimal
+import uuid
 from operator import methodcaller
 
 import dateutil.parser
@@ -39,3 +40,10 @@ Decimal = scalar(
     serialize=str,
     parse_value=decimal.Decimal,
 )
+
+UUID = scalar(
+    uuid.UUID,
+    name="UUID",
+    serialize=str,
+    parse_value=uuid.UUID,
+)
